Content negotiation — parse Accept header to pick codec, decode request body.
Functions
- decode_
request_ grid - Decode a request body into an HGrid using the given Content-Type.
- encode_
response_ grid - Encode an HGrid for the response using the best Accept type.
- parse_
accept - Parse an Accept header and return the best supported MIME type.