pub struct DomainScope { /* private fields */ }Expand description
Scopes federation queries to specific connector domains.
A None domains set means wildcard — all connectors are in scope.
An empty set means no connectors are in scope.
Implementations
Sourceimpl DomainScope
impl DomainScope
Sourcepub fn scoped(domains: impl IntoIterator<Item = String>) -> Self
pub fn scoped(domains: impl IntoIterator<Item = String>) -> Self
Create a scope limited to specific domains.
Sourcepub fn includes(&self, domain: Option<&str>) -> bool
pub fn includes(&self, domain: Option<&str>) -> bool
Check if a domain is included in this scope.
Connectors with None domain are always included in any scope.
Sourcepub fn is_wildcard(&self) -> bool
pub fn is_wildcard(&self) -> bool
Check if this is a wildcard scope.