Module error

Module error 

Haystack error grids and Axum error integration.

Structs

HaystackError
Haystack-specific error type that renders as an error grid in responses.

Functions

error_grid
Build a Haystack error grid with the given message.
grid_from_cols_rows
Helper to create an HGrid with a single empty row and named columns.