error_grid

Function error_grid 

pub fn error_grid(message: &str) -> HGrid
Build a Haystack error grid with the given message.

An error grid has err marker and dis string in its metadata, with no columns and no rows.