grid_from_cols_rows

Function grid_from_cols_rows 

pub fn grid_from_cols_rows(col_names: &[&str], rows: Vec<HDict>) -> HGrid
Helper to create an HGrid with a single empty row and named columns.

Used by op handlers that return simple tabular data.