handle

Function handle 

pub async fn handle(
    req: HttpRequest,
    body: String,
    state: Data<AppState>,
) -> Result<HttpResponse, HaystackError>
POST /api/read

Request grid may have:

  • A filter column with a filter expression string, and optional limit column
  • An id column with Ref values for reading specific entities