pub struct AppState {
pub graph: SharedGraph,
pub namespace: RwLock<DefNamespace>,
pub auth: AuthManager,
pub watches: WatchManager,
pub actions: ActionRegistry,
pub his: Box<dyn HistoryProvider>,
pub started_at: Instant,
}Expand description
Shared application state injected into every Axum handler via State.
Fields
graph: SharedGraphThread-safe entity graph.
namespace: RwLock<DefNamespace>Haystack 4 ontology namespace for def/spec operations.
auth: AuthManagerSCRAM authentication manager.
watches: WatchManagerWatch subscription manager for change polling.
actions: ActionRegistryAction dispatch registry for the invokeAction op.
his: Box<dyn HistoryProvider>Pluggable time-series history store for hisRead/hisWrite.
started_at: InstantInstant when the server was started, used for uptime calculation.