WatchManager

Struct WatchManager 

pub struct WatchManager { /* private fields */ }
Manages watch subscriptions for change polling.

Implementations

Source

impl WatchManager

pub fn new() -> Self

Create a new empty WatchManager.

pub fn subscribe( &self, username: &str, ids: Vec<String>, graph_version: u64, ) -> Result<String, String>

Subscribe to changes on a set of entity IDs.

pub fn poll( &self, watch_id: &str, username: &str, graph: &SharedGraph, ) -> Option<Vec<HDict>>

Poll for changes since the last poll.

pub fn unsubscribe(&self, watch_id: &str, username: &str) -> bool

Unsubscribe a watch by ID.

pub fn add_ids(&self, watch_id: &str, username: &str, ids: Vec<String>) -> bool

Add entity IDs to an existing watch.

pub fn remove_ids(&self, watch_id: &str, username: &str, ids: &[String]) -> bool

Remove specific entity IDs from an existing watch.

pub fn remove_by_owner(&self, owner: &str)

Remove all watches owned by a given user.

pub fn get_ids(&self, watch_id: &str) -> Option<Vec<String>>

Return the list of entity IDs for a given watch.

pub fn len(&self) -> usize

Return the number of active watches.

pub fn is_empty(&self) -> bool

Return whether there are no active watches.

pub fn encode_cached( &self, ref_val: &str, graph_version: u64, entity: &HDict, ) -> Value

Encode an entity using the cache.

pub fn all_watched_ids(&self) -> HashSet<String>

Get the IDs of all entities watched by any watch.

pub fn watches_affected_by( &self, changed_refs: &HashSet<&str>, ) -> Vec<(String, String, Vec<String>)>

Find watches that contain any of the given changed ref_vals.