Action registry for the invokeAction op.
Provides a trait-based dispatch mechanism so that custom action handlers can be registered at startup and invoked by name at runtime.
Structs
- Action
Registry - Registry that maps action names to their handlers.
Traits
- Action
Handler - A handler for a named action that can be invoked on entities.