Module connector

Module connector 

Connector for fetching entities from a remote Haystack server.

Structs

Connector
A connector that can fetch entities from a remote Haystack server.
ConnectorConfig
Configuration for a remote Haystack server connection.

Enums

TransportMode
Transport protocol used by a connector.

Functions

prefix_refs
Prefix all Ref values in an entity dict.
strip_prefix_refs
Strip a prefix from all Ref values in an entity dict.