Connector for fetching entities from a remote Haystack server.
Structs
- Connector
- A connector that can fetch entities from a remote Haystack server.
- Connector
Config - Configuration for a remote Haystack server connection.
Enums
- Transport
Mode - Transport protocol used by a connector.
Functions
- prefix_
refs - Prefix all Ref values in an entity dict.
- strip_
prefix_ refs - Strip a prefix from all Ref values in an entity dict.