Module content

Module content 

Content negotiation — parse Accept header to pick codec, decode request body.

Functions

decode_request_grid
Decode a request body into an HGrid using the given Content-Type.
encode_response_grid
Encode an HGrid for the response using the best Accept type.
parse_accept
Parse an Accept header and return the best supported MIME type.