Haystack error grids and Actix Web error integration.
Structs
- Haystack
Error - Haystack-specific error type that renders as an error grid in responses.
Functions
- error_
grid - Build a Haystack error grid with the given message.
- grid_
from_ cols_ rows - Helper to create an HGrid with a single empty row and named columns.