The invokeAction op — invoke an action on an entity.
invokeAction
Parses id and action columns from the request grid, resolves the entity from the graph, and dispatches to the ActionRegistry.
id
action