pub async fn handle_sub(
req: HttpRequest,
body: String,
state: Data<AppState>,
) -> Result<HttpResponse, HaystackError>Expand description
POST /api/watchSub — subscribe to entity changes.
Request grid has id column with Ref values for entities to watch.
May also have a watchId column to add IDs to an existing watch.
Returns the current state of watched entities with watchId in grid meta.